@@ -43,7 +43,7 @@
  */
 class Locater : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
  public:
 	/**
